#The purpose of this script is to reproduce Touwsranten paper 1 analyses
#07 MARCH 2023

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide stability in 
#(1) positive parenting (2) child internalising (3) externaling (4) parental stress and use of corporal punishment across 3 waves from 2012 to 2016, 
#a baseline period prior to the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix)
#Set current directory
##setwd()

#Import Touwsranten dataset. Subset parent-child dyads with data at both wave 1 & 2 (N = 216) 
Consistentdyads_Waves1to2=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 1|Wave == 2)%>%
  group_by(UniqueDyadID)%>%
  filter(n()==2)%>%
  ungroup()

#Import Touwsranten dataset. Subset parent-child dyads with data at either wave 2 (N=166) or wave 3 (N = 204) but not both
Independentdyads_Waves2to3=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 2|Wave==3)%>%
  group_by(UniqueDyadID)%>%
  filter(!n()==2)%>%
  filter(ChildAge_cat == 1)

##################################################################################################################
#Descriptives of longitudinal subset (with data across waves 1-2) 
#Children aged 6-18 years

Longitudinal.descriptives = Consistentdyads_Waves1to2%>%
  dplyr::select(Wave, ChildGender, ChildAge, APQ_total.wAverage.FINAL,
                APQ_PosPar.subsc, APQ_PoorMon.subsc,APQ_Involvement.subsc,
                SpankHand.APQ, SlapChild.APQ,HitsWithBelt.APQ,CBCL_Older_Internalising.tscore,CBCL_Older_Externalising.tscore,
                CBCL_Older_Externalising.Threshold, CBCL_Older_Internalising.Threshold, CBCL_Older_Externalising.Threshold,
                GHQ_GeneralHealth.subsc, GHQ_GeneralHealth.Threshold, ASSIST_AlcoholSeverity.subsc,
                ASSIST_AlcoholSeverity.Threshold, PSISF_Total_ParentStress.subsc, PSISF_Total_ParentStress.percentile,
                CTS_IPV.subsc, CTS_IPV_categorical)%>%
  mutate_at(vars(SpankHand.APQ,SlapChild.APQ, HitsWithBelt.APQ,GHQ_GeneralHealth.subsc, ASSIST_AlcoholSeverity.subsc), ~as.numeric(.))

gtsummary::tbl_summary(Longitudinal.descriptives, missing = "no", by = Wave,
                       statistic = list(all_continuous() ~ "{mean} ({sd})"), 
                       type =  list(SpankHand.APQ ~ "continuous", SlapChild.APQ ~ "continuous", 
                                    HitsWithBelt.APQ ~ "continuous", CTS_IPV_categorical ~ "categorical",
                                    GHQ_GeneralHealth.subsc ~ "continuous"))%>%
                       bold_labels() %>% modify_header(label = "**Variable**")

#####################################################################################################################################################
#####################################################################################################################################################
#Descriptives of independent subset (with data at waves 2 or 3 both NOT both) 
#Children aged 6-18 years

Independent.descriptives = Independentdyads_Waves2to3%>%
  dplyr::select(Wave, ChildGender, ChildAge, APQ_total.wAverage.FINAL,
                APQ_PosPar.subsc, APQ_PoorMon.subsc,APQ_Involvement.subsc,
                SpankHand.APQ, SlapChild.APQ,HitsWithBelt.APQ,CBCL_Older_Internalising.tscore,CBCL_Older_Externalising.tscore,
                CBCL_Older_Externalising.Threshold, CBCL_Older_Internalising.Threshold, CBCL_Older_Externalising.Threshold,
                GHQ_GeneralHealth.subsc, GHQ_GeneralHealth.Threshold, ASSIST_AlcoholSeverity.subsc,
                ASSIST_AlcoholSeverity.Threshold, PSISF_Total_ParentStress.subsc, PSISF_Total_ParentStress.percentile,
                CTS_IPV.subsc, CTS_IPV_categorical)%>%
  mutate_at(vars(SpankHand.APQ,SlapChild.APQ, HitsWithBelt.APQ), ~as.numeric(.))

gtsummary::tbl_summary(Independent.descriptives, missing = "no", by = Wave,
                       statistic = list(all_continuous() ~ "{mean} ({sd})"), type =  list(SpankHand.APQ ~ "continuous", SlapChild.APQ ~ "continuous", HitsWithBelt.APQ ~ "continuous", CTS_IPV_categorical ~ "categorical"))%>%
                       bold_labels() %>% modify_header(label = "**Variable**")